@@ -1,11 +1,11 @@
-use crate::emu;
+use crate::console::Console;
 use crate::constants;
 use crate::context32::Context32;
-use crate::structures;
+use crate::emu;
 use crate::serialization;
+use crate::structures;
 use crate::winapi32::helper;
 use crate::winapi32::kernel32;
-use crate::console::Console;
 
 use scan_fmt::scan_fmt_some;
 
@@ -47,12 +47,20 @@ pub fn gateway(addr: u32, emu: &mut emu::Emu) -> String {
         _ => {
             if emu.cfg.skip_unimplemented == false {
                 if emu.cfg.dump_on_exit && emu.cfg.dump_filename.is_some() {
-                    serialization::Serialization::dump_to_file(&emu, emu.cfg.dump_filename.as_ref().unwrap());
+                    serialization::Serialization::dump_to_file(
+                        &emu,
+                        emu.cfg.dump_filename.as_ref().unwrap(),
+                    );
                 }
 
                 unimplemented!("atemmpt to call unimplemented API 0x{:x} {}", addr, api);
             }
-            log::warn!("calling unimplemented API 0x{:x} {} at 0x{:x}", addr, api, emu.regs.rip);
+            log::warn!(
+                "calling unimplemented API 0x{:x} {} at 0x{:x}",
+                addr,
+                api,
+                emu.regs.rip
+            );
             return api;
         }
     }
